﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Common;

namespace HeuristicLab.Analysis.AlgorithmBehavior.Analyzers {
  public class VertexComparer : Comparer<double[]> {
    public double[] d;
    public double[] r;

    private double CalculateWeight(double[] x) {
      double max = double.MinValue;
      for (int i = 0; i < x.Length; i++) {
        double w = (x[i] - d[i]) / r[i];
        if (w > max) max = w;
      }
      return max;
    }

    public override int Compare(double[] x, double[] y) {
      double xw = CalculateWeight(x);
      double yw = CalculateWeight(y);

      if (xw.IsAlmost(yw))
        return 0;
      if (xw > yw)
        return 1;
      return -1; /*if (xw < yw)*/
    }
  }
}
